@@ -11,6 +11,7 @@
 #' @param homog Homogeneity test of variances (\emph{default} is Bartlett)
 #' @param mcomp Multiple comparison test (Tukey (\emph{default}), LSD, Scott-Knott and Duncan)
 #' @param quali Defines whether the factor is quantitative or qualitative (\emph{qualitative})
+#' @param names.fat Name of factors
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
 #' @param transf Applies data transformation (default is 1; for log consider 0; `angular` for angular transformation)
@@ -100,6 +101,7 @@ FAT2DBC=function(f1,
                  alpha.f = 0.05,
                  alpha.t = 0.05,
                  quali = c(TRUE, TRUE),
+                 names.fat=c("F1", "F2"),
                  mcomp = "tukey",
                  grau=c(NA,NA),
                  grau12=NA, # F1/F2
@@ -165,7 +167,6 @@ FAT2DBC=function(f1,
   nv2 <- length(summary(Fator2))
   lf1 <- levels(Fator1)
   lf2 <- levels(Fator2)
-  fac.names = c("F1", "F2")
   fatores <- data.frame(Fator1, Fator2)
   graph=data.frame(Fator1,Fator2,resp)
   a=anova(aov(resp~Fator1*Fator2+bloco))
@@ -195,7 +196,7 @@ FAT2DBC=function(f1,
     method=paste("Bartlett test","(",names(statistic),")",sep="")
   }
   if(homog=="levene"){
-    homog1 = levenehomog(c$res~trat)
+    homog1 = levenehomog(c$res~trat)[1,]
     statistic=homog1$`F value`[1]
     phomog=homog1$`Pr(>F)`[1]
     method="Levene's Test (center = median)(F)"
@@ -267,6 +268,8 @@ FAT2DBC=function(f1,
   cat(green(bold("\n-----------------------------------------------------------------\n")))
   anava1=as.matrix(data.frame(anava))
   colnames(anava1)=c("Df","Sum Sq","Mean.Sq","F value","Pr(F)" )
+  rownames(anava1)=c(names.fat[1],names.fat[2],"Block",
+                     paste(names.fat[1],"x",names.fat[2]),"Residuals")
   print(anava1,na.print = "")
   cat("\n")
   if(transf==1 && norm1$p.value<0.05 | transf==1 && indep$p.value<0.05 | transf==1 &&homog1$p.value<0.05){
@@ -284,7 +287,7 @@ FAT2DBC=function(f1,
 
     for (i in 1:2) {if (a$`Pr(>F)`[i] <= alpha.f){
       cat(green(bold("\n-----------------------------------------------------------------\n")))
-      cat(bold(fac.names[i]))
+      cat(bold(names.fat[i]))
       cat(green(bold("\n-----------------------------------------------------------------\n")))
       if(quali[i]==TRUE){
       if(mcomp=="tukey"){
@@ -440,7 +443,7 @@ FAT2DBC=function(f1,
     cat(green(bold("\nSignificant interaction: analyzing the interaction\n")))
     cat(green(bold("\n-----------------------------------------------------------------\n")))
     cat("\n-----------------------------------------------------------------\n")
-    cat("Analyzing ", fac.names[1], " inside of each level of ",fac.names[2])
+    cat("Analyzing ", names.fat[1], " inside of each level of ",names.fat[2])
     cat("\n-----------------------------------------------------------------\n")
     des1<-aov(resp~ bloco + Fator2/Fator1)
     l1<-vector('list',nv2)
@@ -451,7 +454,16 @@ FAT2DBC=function(f1,
       l1[[j]]<-v
       v<-numeric(0)
     }
+    rn<-numeric(0)
+    for (j in 1:nv2) {
+      rn <- c(rn, paste(paste(names.fat[1], ":", names.fat[2],
+                              sep = ""), lf2[j]))
+    }
     des1.tab<-summary(des1,split=list('Fator2:Fator1'=l1))[[1]]
+    rownames(des1.tab)=c("Block",names.fat[2],
+                         paste(names.fat[1],"x",names.fat[2],"+",names.fat[1]),
+                         paste("  ",rn),"Residuals")
+
     print(des1.tab)
     desdobramento1=des1.tab
     if(quali[1]==TRUE & quali[2]==TRUE){
@@ -522,7 +534,7 @@ FAT2DBC=function(f1,
           sk=data.frame(respi=medias,groups=sk)
           # sk=sk(respi,trati,a$Df[5], a$`Sum Sq`[5],alpha.t)
           if(transf !="1"){sk$respo=tapply(response[Fator2 == lf2[i]],
-                                           trati,mean, na.rm=TRUE)[rownames(sk$groups)]}
+                                           trati,mean, na.rm=TRUE)[rownames(sk)]}
           skgrafico[[i]]=sk[levels(trati),2]
           ordem[[i]]=rownames(sk[levels(trati),])
         }
@@ -534,7 +546,7 @@ FAT2DBC=function(f1,
     }
 
     cat("\n-----------------------------------------------------------------\n")
-    cat("Analyzing ", fac.names[2], " inside of the level of ",fac.names[1])
+    cat("Analyzing ", names.fat[2], " inside of the level of ",names.fat[1])
     cat("\n-----------------------------------------------------------------\n")
     cat("\n")
     des2<-aov(resp~ bloco + Fator1/Fator2)
@@ -547,7 +559,16 @@ FAT2DBC=function(f1,
       l2[[j]]<-v
       v<-numeric(0)
     }
+
+    rn<-numeric(0)
+    for (i in 1:nv1) {
+      rn <- c(rn, paste(paste(names.fat[2], ":", names.fat[1],
+                              sep = ""), lf1[i]))
+    }
     des2.tab<-summary(des2,split=list('Fator1:Fator2'=l2))[[1]]
+    rownames(des2.tab)=c("Block",names.fat[1],
+                         paste(names.fat[1],"x",names.fat[2],"+",names.fat[2]),
+                         paste("  ",rn),"Residuals")
     print(des2.tab)
     desdobramento2=des2.tab
 
