@@ -12,6 +12,7 @@
 #' @param geom graph type (columns or segments)
 #' @param width.bar width of the error bars of a regression graph.
 #' @param pointsize Point size
+#' @param facet.background Color background in facet
 #' @export
 #' @return Returns a bar chart for one factor
 #'
@@ -31,7 +32,8 @@ barfacet=function(model,
                   geom="bar",
                   fill="lightblue",
                   pointsize=4.5,
-                  width.bar=0.15){
+                  width.bar=0.15,
+                  facet.background="gray80"){
   requireNamespace("ggplot2")
   data=model[[1]]$data
   media=data$media
@@ -55,7 +57,7 @@ barfacet=function(model,
                        y=media))+
         theme+
         geom_errorbar(aes(ymin=media-desvio,
-                          ymax=media+desvio),width=width.bar)+
+                          ymax=media+desvio),width=model[[1]]$plot$width.bar)+
         geom_point(fill=fill,shape=21,size=pointsize,color="black")+
         geom_text(aes(y=media+desvio+sup,
                       x=trats,
@@ -63,10 +65,12 @@ barfacet=function(model,
         labs(x=model[[1]]$labels$x,
              y=model[[1]]$labels$y)+
         facet_grid(~fac,scales = "free", space='free')+
-        theme(axis.text = element_text(size=12,color="black"),
-              strip.text = element_text(size=12),
-              legend.position = "none")+
-        ylim(layer_scales(model[[1]])$y$range$range)}
+        theme(axis.text = element_text(size=model[[1]]$plot$textsize,color="black"),
+              strip.text = element_text(size=model[[1]]$plot$textsize),
+              legend.position = "none",
+              # axis.text.x = element_text(angle = model[[1]]$plot$angle),
+              strip.background = element_rect(fill=facet.background))+
+        ylim(layer_scales(model[[1]])$y$range$range*1.1)}
     if(geom=="bar" & horiz==FALSE){
       graph=ggplot(data,
                    aes(x=trats,
@@ -74,24 +78,26 @@ barfacet=function(model,
         theme+
         geom_col(fill=fill,size=0.3,color="black")+
         geom_errorbar(aes(ymin=media-desvio,
-                          ymax=media+desvio),width=0.2)+
+                          ymax=media+desvio),width=model[[1]]$plot$width.bar)+
         geom_text(aes(y=media+desvio+sup,
                       x=trats,
                       label = letra),vjust=0)+
         labs(x=model[[1]]$labels$x,
              y=model[[1]]$labels$y)+
         facet_grid(~fac,scales = "free", space='free')+
-        theme(axis.text = element_text(size=12,color="black"),
-              strip.text = element_text(size=12),
-              legend.position = "none")+
-        ylim(layer_scales(model[[1]])$y$range$range)}}
+        theme(axis.text = element_text(size=model[[1]]$plot$textsize,color="black"),
+              strip.text = element_text(size=model[[1]]$plot$textsize),
+              legend.position = "none",
+              # axis.text.x = element_text(angle = model[[1]]$plot$angle),
+              strip.background = element_rect(fill=facet.background))+
+        ylim(layer_scales(model[[1]])$y$range$range*1.1)}}
   if(geom=="point" & horiz==TRUE){
     graph=ggplot(data,
                  aes(y=trats,
                      x=media))+
       theme+
       geom_errorbar(aes(xmin=media-desvio,
-                        xmax=media+desvio),width=width.bar)+
+                        xmax=media+desvio),width=model[[1]]$plot$width.bar)+
       geom_point(fill=fill,shape=21,size=pointsize,color="black")+
       geom_text(aes(x=media+desvio+sup,
                     y=trats,
@@ -99,10 +105,10 @@ barfacet=function(model,
       labs(y=model[[1]]$labels$x,
            x=model[[1]]$labels$y)+
       facet_grid(fac,scales = "free", space='free')+
-      theme(axis.text = element_text(size=12,color="black"),
-            strip.text = element_text(size=12),
-            legend.position = "none")+
-      xlim(layer_scales(model[[1]])$y$range$range)}
+      theme(axis.text = element_text(size=model[[1]]$plot$textsize,color="black"),
+            strip.text = element_text(size=model[[1]]$plot$textsize),
+            legend.position = "none",strip.background = element_rect(fill=facet.background))+
+      xlim(layer_scales(model[[1]])$y$range$range*1.1)}
   if(geom=="bar" & horiz==TRUE){
     graph=ggplot(data,
                  aes(y=trats,
@@ -110,15 +116,15 @@ barfacet=function(model,
       theme+
       geom_col(fill=fill,size=0.3,color="black")+
       geom_errorbar(aes(xmin=media-desvio,
-                        xmax=media+desvio),width=0.2)+
+                        xmax=media+desvio),width=model[[1]]$plot$width.bar)+
       geom_text(aes(x=media+desvio+sup,
                     y=trats,
                     label = letra),hjust=0)+
       labs(y=model[[1]]$labels$x,
            x=model[[1]]$labels$y)+
       facet_grid(fac,scales = "free", space='free')+
-      theme(axis.text = element_text(size=12,color="black"),
-            strip.text = element_text(size=12),
-            legend.position = "none")+
-      xlim(layer_scales(model[[1]])$y$range$range)}
+      theme(axis.text = element_text(size=model[[1]]$plot$textsize,color="black"),
+            strip.text = element_text(size=model[[1]]$plot$textsize),
+            legend.position = "none",strip.background = element_rect(fill=facet.background))+
+      xlim(layer_scales(model[[1]])$y$range$range*1.1)}
 graph}
